module.exports = defineTest({
	description: 'handles loops with destructuring declarations'
});
